# distributions-harsh package

This is a simple distributions package for calculating Gaussian and Binomial distributions.

## Files

- Generaldistribution.py

Generic distribution class for calculating and visualizing a probability distribution.

- Gaussiandistribution.py

Gaussian distribution class for calculating and visualizing a Gaussian distribution.

- Binomialdistribution.py

Binomial distribution class for calculating and visualizing a Binomial distribution.

## Installation

`pip install distributions-harsh`
